@@ -1,5 +1,5 @@
 package App::intrunningsum;
-$App::intrunningsum::VERSION = '0.0.2';
+$App::intrunningsum::VERSION = '0.0.3';
 use strict;
 use warnings;
 
@@ -18,7 +18,7 @@ sub new
 
 sub _init
 {
-    my ($self, $args) = @_;
+    my ( $self, $args ) = @_;
 
     return;
 }
@@ -27,10 +27,10 @@ sub run
 {
     my $s = Math::GMP->new('0');
 
-    while (my $l = <ARGV>)
+    while ( my $l = <ARGV> )
     {
-        chomp$l;
-        print (($s += Math::GMP->new($l)), "\n");
+        chomp $l;
+        print( ( $s += Math::GMP->new($l) ), "\n" );
     }
 
     return;
@@ -42,13 +42,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::intrunningsum - running sum of decimal big integers from stdin or files
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -73,28 +75,7 @@ Constructor - for internal use.
 
 Run the app - for internal use.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2017 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/app-intrunningsum/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -115,14 +96,6 @@ L<https://metacpan.org/release/App-intrunningsum>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-intrunningsum>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -131,22 +104,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-intrunningsum>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-intrunningsum>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-intrunningsum>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -195,4 +152,25 @@ L<https://github.com/shlomif/App-intsum>
 
   git clone https://github.com/shlomif/App-intsum.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/app-intrunningsum/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
